<?php
/**
 * @package    Proxim
 * @author     Davison Pro <davisonpro.coder@gmail.com | https://davisonpro.dev>
 * @copyright  2019 Proxim
 * @version    1.0.0
 * @since      File available since Release 1.0.0
 */

require_once dirname(__FILE__) . DIRECTORY_SEPARATOR . 'prox-bootstrap.php';

if (!defined('ABSPATH') ) {
    define('ABSPATH', dirname(__FILE__) . '/');
}

require_once dirname(__FILE__) . DIRECTORY_SEPARATOR . 'wp-config.php';
require_once dirname(__FILE__) . DIRECTORY_SEPARATOR . 'wp-settings.php';

$app->registerStylesheet('wp-css', get_stylesheet_uri(), ['media' => 'all', 'server' => 'remote']);
$app->registerJavascript('wp-js', get_theme_file_uri( '/assets/js/main.js' ), ['position' => 'bottom', 'media' => 'all', 'server' => 'remote']);

$menu_locations = get_nav_menu_locations();
$header_servicesID = $menu_locations['header_services_links'];
$header_mainID = $menu_locations['header_main_nav'];

$header_services_links = wp_get_nav_menu_items($header_servicesID);
$header_main_nav = wp_get_nav_menu_items($header_mainID);

$smarty = $app->container->smarty;

$primary_color =  get_theme_mod('primary_color_type') == "custom" ? get_theme_mod('primary_color') : "#fec137";
$header_links_color = get_theme_mod('header_links_color_type') == "custom" ? get_theme_mod('header_links_color') : "#2f5654";
$secondary_color = get_theme_mod('secondary_color_type') == "custom" ? get_theme_mod('secondary_color') : "#ffffff";
$footer_color = get_theme_mod('footer_color_type') == "custom" ? get_theme_mod('footer_color') : "#00395a";
$patch_color = get_theme_mod('patch_color_type') == "custom" ? get_theme_mod('patch_color') : "#00395a";

$smarty->assign([
    'primary_color' => $primary_color,
    'header_links_color' => $header_links_color,
    'secondary_color' => $secondary_color,
    'header_services_links' => $header_services_links,
    'header_main_nav' => $header_main_nav
]);

use Proxim\Tools;
use Proxim\Util\ArrayUtils;

$templateVars = array(
    'page' => [
        'title' => 'Place a New Inquiry',
        'description' => 'Place a New Inquiry'
    ],
    'app' => 'standalone-form',
    'orderformPurpose' => 'newInquiry',
    'target' => 'order',
);

$defaultCountry = array();
if ( $app->container->cookie->country_code ) {
    $countries = $globals['countries'];
    $country_code = Tools::strtolower($app->container->cookie->country_code);

    if ( ArrayUtils::has($countries, $country_code) ) {
        $country = ArrayUtils::get($countries, $country_code);
        $defaultCountry = array(
            "id" => $country_code,
            "name" => ArrayUtils::get($country, 'name'),
            "code" => ArrayUtils::get($country, 'code'),
            "phoneCode" => ArrayUtils::get($country, 'phoneCode')
        );
    }
}

$templateVars = array_merge($templateVars, $defaultCountry);

$app->setVars($templateVars);

$app->setTemplate('inquiry');
$app->display();